# Core Developers

----------
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi))
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri))

# Other Contributors
- Mohammad Hosein Moslemi - [@mhmoslemi2338](https://github.com/mhmoslemi2338)
- Evan Slack - [@evanofslack](https://github.com/evanofslack)
----------